import React, { useState } from "react";
import Dialog from "@mui/material/Dialog";
import DialogActions from "@mui/material/DialogActions";
import DialogContent from "@mui/material/DialogContent";
import DialogContentText from "@mui/material/DialogContentText";
import DialogTitle from "@mui/material/DialogTitle";
import Button from "@mui/material/Button";
import TextField from "@mui/material/TextField";
import { createTheme, ThemeProvider } from '@mui/material/styles';

// Create a custom theme that matches our design system
const theme = createTheme({
  palette: {
    primary: {
      main: '#22c55e', // primary-600 color
    },
    secondary: {
      main: '#6366f1', // secondary-500 color
    },
    background: {
      default: '#0f172a', // dark-900 color
      paper: '#1e293b', // dark-800 color
    },
    text: {
      primary: '#f8fafc',
      secondary: '#94a3b8',
    },
  },
  typography: {
    fontFamily: 'Inter, system-ui, sans-serif',
  },
  shape: {
    borderRadius: 8,
  },
  components: {
    MuiButton: {
      styleOverrides: {
        root: {
          textTransform: 'none',
          fontWeight: 500,
        },
      },
    },
    MuiDialog: {
      styleOverrides: {
        paper: {
          borderRadius: 12,
        },
      },
    },
  },
});

const MailingListDialog = ({ open, onClose }) => {
  const [name, setName] = useState("");
  const [email, setEmail] = useState("");
  const [error, setError] = useState("");
  const [success, setSuccess] = useState("");

  const handleSubmit = (e) => {
    e.preventDefault();
    setError("");
    setSuccess("");

    // Basic validation
    if (!name.trim() || !email.trim()) {
      setError("Please fill in all fields");
      return;
    }

    // Email validation
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    if (!emailRegex.test(email)) {
      setError("Please enter a valid email address");
      return;
    }

    const form = document.createElement("form");
    form.action = "https://tech.us9.list-manage.com/subscribe/post";
    form.method = "POST";
    form.target = "_blank";

    const hiddenFields = {
      u: "aaf43cf1740b320b738dade27",
      id: "344e2f39e6",
      MERGE1: name,
      MERGE0: email,
    };

    Object.keys(hiddenFields).forEach((key) => {
      const input = document.createElement("input");
      input.type = "hidden";
      input.name = key;
      input.value = hiddenFields[key];
      form.appendChild(input);
    });

    document.body.appendChild(form);
    form.submit();
    document.body.removeChild(form);

    setSuccess("Thank you for subscribing!");
    setName("");
    setEmail("");
    
    // Close the dialog after a short delay to allow user to see the success message
    setTimeout(() => {
      onClose();
    }, 1500);
  };

  return (
    <ThemeProvider theme={theme}>
      <Dialog 
        open={open} 
        onClose={onClose}
        PaperProps={{
          sx: {
            bgcolor: 'background.paper',
            color: 'text.primary',
            maxWidth: '500px',
            width: '100%',
          }
        }}
      >
        <DialogTitle sx={{ fontSize: '1.5rem', fontWeight: 700, pb: 1 }}>
          Join Our Community
        </DialogTitle>
        
        <DialogContent>
          <DialogContentText sx={{ color: 'text.secondary', mb: 3 }}>
            Get exclusive access to roadmaps, resources, and updates to accelerate your tech journey.
          </DialogContentText>
          
          <TextField
            autoFocus
            margin="dense"
            id="name"
            label="Full Name"
            type="text"
            fullWidth
            variant="outlined"
            value={name}
            onChange={(e) => setName(e.target.value)}
            sx={{ 
              mb: 2,
              '& .MuiOutlinedInput-root': {
                '& fieldset': {
                  borderColor: 'rgba(148, 163, 184, 0.2)',
                },
                '&:hover fieldset': {
                  borderColor: 'primary.main',
                },
              },
              '& .MuiInputLabel-root': {
                color: 'text.secondary',
              },
              '& .MuiInputBase-input': {
                color: 'text.primary',
              }
            }}
          />
          
          <TextField
            margin="dense"
            id="email"
            label="Email Address"
            type="email"
            fullWidth
            variant="outlined"
            value={email}
            onChange={(e) => setEmail(e.target.value)}
            sx={{ 
              mb: 2,
              '& .MuiOutlinedInput-root': {
                '& fieldset': {
                  borderColor: 'rgba(148, 163, 184, 0.2)',
                },
                '&:hover fieldset': {
                  borderColor: 'primary.main',
                },
              },
              '& .MuiInputLabel-root': {
                color: 'text.secondary',
              },
              '& .MuiInputBase-input': {
                color: 'text.primary',
              }
            }}
          />
          
          <DialogContentText sx={{ mt: 2, fontSize: '0.85rem', color: 'text.secondary', opacity: 0.8 }}>
            We promise not to sell your information or email you more than once or
            twice a month.
          </DialogContentText>
          
          {error && (
            <DialogContentText sx={{ mt: 2, color: '#ef4444', fontSize: '0.875rem' }}>
              {error}
            </DialogContentText>
          )}
          
          {success && (
            <DialogContentText sx={{ mt: 2, color: 'primary.main', fontSize: '0.875rem' }}>
              {success}
            </DialogContentText>
          )}
        </DialogContent>
        
        <DialogActions sx={{ px: 3, pb: 3 }}>
          <Button 
            onClick={onClose} 
            sx={{ 
              color: 'text.secondary',
              '&:hover': {
                backgroundColor: 'rgba(148, 163, 184, 0.1)',
              }
            }}
          >
            Cancel
          </Button>
          
          <Button 
            onClick={handleSubmit} 
            variant="contained" 
            color="primary"
            sx={{ 
              px: 4,
              '&:hover': {
                backgroundColor: 'primary.dark',
              }
            }}
          >
            Subscribe
          </Button>
        </DialogActions>
      </Dialog>
    </ThemeProvider>
  );
};

export default MailingListDialog;